Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2306)

Unified Diff: third_party/WebKit/Source/core/animation/Animation.cpp

Issue 2948193002: Merge AnimationTimeline and DocumentTimeline (Closed)
Patch Set: Fix rebase error Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/animation/Animation.cpp
diff --git a/third_party/WebKit/Source/core/animation/Animation.cpp b/third_party/WebKit/Source/core/animation/Animation.cpp
index bd3225a61e3d3554eb391a103b7f23fc5a7bb609..3cc67287b74999c9b675c05da00851058bf6e936 100644
--- a/third_party/WebKit/Source/core/animation/Animation.cpp
+++ b/third_party/WebKit/Source/core/animation/Animation.cpp
@@ -30,7 +30,6 @@
#include "core/animation/Animation.h"
-#include "core/animation/AnimationTimeline.h"
#include "core/animation/CompositorPendingAnimations.h"
#include "core/animation/DocumentTimeline.h"
#include "core/animation/KeyframeEffectReadOnly.h"
@@ -70,13 +69,13 @@ static unsigned NextSequenceNumber() {
Animation* Animation::Create(AnimationEffectReadOnly* effect,
SuperAnimationTimeline* timeline) {
- if (!timeline || !timeline->IsAnimationTimeline()) {
+ if (!timeline || !timeline->IsDocumentTimeline()) {
// FIXME: Support creating animations without a timeline.
NOTREACHED();
return nullptr;
}
- AnimationTimeline* subtimeline = ToAnimationTimeline(timeline);
+ DocumentTimeline* subtimeline = ToDocumentTimeline(timeline);
Animation* animation = new Animation(
subtimeline->GetDocument()->ContextDocument(), *subtimeline, effect);
@@ -112,7 +111,7 @@ Animation* Animation::Create(ExecutionContext* execution_context,
}
Animation::Animation(ExecutionContext* execution_context,
- AnimationTimeline& timeline,
+ DocumentTimeline& timeline,
AnimationEffectReadOnly* content)
: ContextLifecycleObserver(execution_context),
play_state_(kIdle),
@@ -151,7 +150,7 @@ Animation::~Animation() {
void Animation::Dispose() {
DestroyCompositorPlayer();
// If the AnimationTimeline and its Animation objects are
// finalized by the same GC, we have to eagerly clear out
// this Animation object's compositor player registration.
DCHECK(!compositor_player_);
@@ -151,7 +150,7 @@ Animation::~Animation() {
void Animation::Dispose() {
DestroyCompositorPlayer();
- // If the AnimationTimeline and its Animation objects are
+ // If the DocumentTimeline and its Animation objects are
// finalized by the same GC, we have to eagerly clear out
// this Animation object's compositor player registration.
« no previous file with comments | « third_party/WebKit/Source/core/animation/Animation.h ('k') | third_party/WebKit/Source/core/animation/AnimationTest.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698